summaryrefslogtreecommitdiff
path: root/svx
diff options
context:
space:
mode:
authorRüdiger Timm <rt@openoffice.org>2003-10-27 12:26:59 +0000
committerRüdiger Timm <rt@openoffice.org>2003-10-27 12:26:59 +0000
commit7bb9efca06efb714b1531af1873609c4dbfdc8ec (patch)
tree131b206dba2a26855e2575b966fabf629ed076ed /svx
parent75c447611f2692ea3332b71be5779a5c4b6da9e5 (diff)
INTEGRATION: CWS aw005 (1.7.250); FILE MERGED
2003/10/16 11:22:19 aw 1.7.250.2: #i21250# Instead of simply passing sal_True as LineToArea, use bNoPolyPoly as info if this command is a 'Combine' or a 'Connect' command. On Connect it's sal_True. To not concert line segments with a set line width to polygons in that case, use this info. Do not convert LineToArea on Connect commands. 2003/10/10 11:13:30 aw 1.7.250.1: #110635# Take fill style/closed state of pAttrObj in account when deciding to change the line style
Diffstat (limited to 'svx')
-rw-r--r--svx/source/svdraw/svdedtv2.cxx24
1 files changed, 18 insertions, 6 deletions
diff --git a/svx/source/svdraw/svdedtv2.cxx b/svx/source/svdraw/svdedtv2.cxx
index e39d6c88ab8f..dd3e3d2f9e7c 100644
--- a/svx/source/svdraw/svdedtv2.cxx
+++ b/svx/source/svdraw/svdedtv2.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: svdedtv2.cxx,v $
*
- * $Revision: 1.7 $
+ * $Revision: 1.8 $
*
- * last change: $Author: rt $ $Date: 2003-04-24 14:48:35 $
+ * last change: $Author: rt $ $Date: 2003-10-27 13:26:59 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -1124,7 +1124,13 @@ BOOL SdrEditView::CombineMarkedObjects(BOOL bNoPolyPoly)
// ConvertMarkedToPolyObj was too strong here, it will loose quality and
// information when curve objects are combined. This can be replaced by
// using ConvertMarkedToPathObj without changing the previous fix.
- ConvertMarkedToPathObj(sal_True);
+
+ // #i21250#
+ // Instead of simply passing sal_True as LineToArea, use bNoPolyPoly as info
+ // if this command is a 'Combine' or a 'Connect' command. On Connect it's sal_True.
+ // To not concert line segments with a set line width to polygons in that case,
+ // use this info. Do not convert LineToArea on Connect commands.
+ ConvertMarkedToPathObj(!bNoPolyPoly);
// continue as before
bCombineError = FALSE;
@@ -1215,9 +1221,15 @@ BOOL SdrEditView::CombineMarkedObjects(BOOL bNoPolyPoly)
// Attribute des untersten Objekts
ImpCopyAttributes(pAttrObj,pPath);
- // #100408# If LineStyle is XLINE_NONE force to XLINE_SOLID to make visible.
- const XLineStyle eLineStyle = ((const XLineStyleItem&)pPath->GetItem(XATTR_LINESTYLE)).GetValue();
- if(XLINE_NONE == eLineStyle)
+ // #100408# If LineStyle of pAttrObj is XLINE_NONE force to XLINE_SOLID to make visible.
+ const XLineStyle eLineStyle = ((const XLineStyleItem&)pAttrObj->GetItem(XATTR_LINESTYLE)).GetValue();
+ const XFillStyle eFillStyle = ((const XFillStyleItem&)pAttrObj->GetItem(XATTR_FILLSTYLE)).GetValue();
+
+ // #110635#
+ // Take fill style/closed state of pAttrObj in account when deciding to change the line style
+ sal_Bool bIsClosedPathObj(pAttrObj->ISA(SdrPathObj) && ((SdrPathObj*)pAttrObj)->IsClosed());
+
+ if(XLINE_NONE == eLineStyle && (XFILL_NONE == eFillStyle || !bIsClosedPathObj))
{
pPath->SetItem(XLineStyleItem(XLINE_SOLID));
}